FormatSyntax

Struct FormatSyntax 

pub struct FormatSyntax {
    pub omit_src_dst_same_reg: Option<bool>,
    pub omit_src_dst_diff_reg: Option<bool>,
    pub omit_deref_null_const: Option<bool>,
    pub positive_integer_format: Option<FormatInteger>,
    pub negative_integer_format: Option<FormatInteger>,
}
Type that represents the per-instruction syntax settings.

Fields

omit_src_dst_same_reg: Option<bool>

Settings for a register that can be omitted when it is used as both the source and the destination. For example, in ADCS{<q>} {<Rdn>, }<Rdn>, <Rm>, this would control whether or not <Rdn> is displayed.

If None, defaults to the corresponding global configuration value.

omit_src_dst_diff_reg: Option<bool>

Controls if a register that can be omitted when it can be used as both the source and the destination should be displayed. For example, in ADC{<c>}{<q>} {<Rd>, }<Rn>, <Rm>, RRX, this would control whether or not <Rd> is displayed if <Rd> == <Rn>.

If None, defaults to the corresponding global configuration value.

omit_deref_null_const: Option<bool>

Controls if optional null integers in dereferencing groups should be displayed. For example, in LDXRB <Wt>, [<Xn|SP>{, #0}], this would control whether or not #0 is displayed.

If None, defaults to the corresponding global configuration value.

positive_integer_format: Option<FormatInteger>

Controls how positive numbers are displayed.

If None, defaults to the corresponding global configuration value.

negative_integer_format: Option<FormatInteger>

Controls how negative numbers are displayed.

If None, defaults to the corresponding global configuration value.

Implementations