pub struct EncoderBlock { /* private fields */ }Expand description
Type that represents an encoder block, which is a collection of
Implementations
Sourceimpl EncoderBlock
impl EncoderBlock
Sourcepub fn new(instr_blocks: Vec<InstructionBlock>) -> Self
pub fn new(instr_blocks: Vec<InstructionBlock>) -> Self
Creates a new encoder block from a vector of instruction blocks.
Sourcepub fn encode(self) -> Result<Vec<EncoderBlockResult>>
pub fn encode(self) -> Result<Vec<EncoderBlockResult>>
Encodes all instructions in the encoder block.