pub struct EncoderBlockResult {
pub pc: u64,
pub data: Vec<u8>,
}Expand description
Type that represents the result of an encoder block after being assembled.
Fields
pc: u64data: Vec<u8>Trait Implementations
Sourceimpl Clone for EncoderBlockResult
impl Clone for EncoderBlockResult
Sourcefn clone(&self) -> EncoderBlockResult
fn clone(&self) -> EncoderBlockResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EncoderBlockResult
impl Debug for EncoderBlockResult
Sourceimpl Default for EncoderBlockResult
impl Default for EncoderBlockResult
Sourcefn default() -> EncoderBlockResult
fn default() -> EncoderBlockResult
Returns the “default value” for a type. Read more
impl Eq for EncoderBlockResult
Sourceimpl Hash for EncoderBlockResult
impl Hash for EncoderBlockResult
Sourceimpl Ord for EncoderBlockResult
impl Ord for EncoderBlockResult
Sourcefn cmp(&self, other: &EncoderBlockResult) -> Ordering
fn cmp(&self, other: &EncoderBlockResult) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EncoderBlockResult
impl PartialEq for EncoderBlockResult
Sourcefn eq(&self, other: &EncoderBlockResult) -> bool
fn eq(&self, other: &EncoderBlockResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for EncoderBlockResult
impl PartialOrd for EncoderBlockResult
impl StructuralPartialEq for EncoderBlockResult