pub enum FormatAliasInstruction<A> {
Never,
Recommended,
Preferred(A),
Always(A),
}Expand description
Type that represents the per-instruction alias settings.
It specifies Charm’s behavior for a given encoding when using an alias is possible.
Variants
Never
Never use the alias, regardless of any condition.
Recommended
Follows ARM’s recommendations.
Preferred(A)
If multiple aliases are possible, try to use this alias first.
Always(A)
Always use the alias, regardless of any condition.